@@ -1,15 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef PROGRESSSTATUSBARWIDGET_H
 #define PROGRESSSTATUSBARWIDGET_H
 
-#include <QObject>
 #include "kdepim_export.h"
+#include <QObject>
 
-namespace KPIM {
+namespace KPIM
+{
 class StatusbarProgressWidget;
 class ProgressStatusBarWidgetPrivate;
 /**
